@@ -54,8 +54,11 @@ func init() {
 	downloadAppledbCmd.Flags().String("pattern", "", "Download remote files that match regex")
 	downloadAppledbCmd.Flags().Bool("fcs-keys", false, "Download AEA1 DMG fcs-key pem files")
 	downloadAppledbCmd.Flags().Bool("fcs-keys-json", false, "Download AEA1 DMG fcs-keys as JSON")
+	downloadAppledbCmd.Flags().Bool("release", false, "Download release IPSWs")
 	downloadAppledbCmd.Flags().Bool("beta", false, "Download beta IPSWs")
+	downloadAppledbCmd.Flags().Bool("rc", false, "Download RC (release candidate) IPSWs")
 	downloadAppledbCmd.Flags().Bool("latest", false, "Download latest IPSWs")
+	downloadAppledbCmd.Flags().Bool("show-latest", false, "Show latest version/build")
 	downloadAppledbCmd.Flags().StringP("prereq-build", "p", "", "OTA prerequisite build")
 	downloadAppledbCmd.Flags().BoolP("urls", "u", false, "Dump URLs only")
 	downloadAppledbCmd.Flags().BoolP("json", "j", false, "Dump DB query results as JSON")
@@ -64,6 +67,7 @@ func init() {
 	downloadAppledbCmd.Flags().StringP("output", "o", "", "Folder to download files to")
 	downloadAppledbCmd.Flags().BoolP("flat", "f", false, "Do NOT perserve directory structure when downloading with --pattern")
 	downloadAppledbCmd.Flags().Bool("usb", false, "Download IPSWs for USB attached iDevices")
+	downloadAppledbCmd.MarkFlagsMutuallyExclusive("release", "beta", "rc")
 
 	viper.BindPFlag("download.appledb.os", downloadAppledbCmd.Flags().Lookup("os"))
 	viper.BindPFlag("download.appledb.type", downloadAppledbCmd.Flags().Lookup("type"))
@@ -72,8 +76,11 @@ func init() {
 	viper.BindPFlag("download.appledb.pattern", downloadAppledbCmd.Flags().Lookup("pattern"))
 	viper.BindPFlag("download.appledb.fcs-keys", downloadAppledbCmd.Flags().Lookup("fcs-keys"))
 	viper.BindPFlag("download.appledb.fcs-keys-json", downloadAppledbCmd.Flags().Lookup("fcs-keys-json"))
+	viper.BindPFlag("download.appledb.release", downloadAppledbCmd.Flags().Lookup("release"))
 	viper.BindPFlag("download.appledb.beta", downloadAppledbCmd.Flags().Lookup("beta"))
+	viper.BindPFlag("download.appledb.rc", downloadAppledbCmd.Flags().Lookup("rc"))
 	viper.BindPFlag("download.appledb.latest", downloadAppledbCmd.Flags().Lookup("latest"))
+	viper.BindPFlag("download.appledb.show-latest", downloadAppledbCmd.Flags().Lookup("show-latest"))
 	viper.BindPFlag("download.appledb.prereq-build", downloadAppledbCmd.Flags().Lookup("prereq-build"))
 	viper.BindPFlag("download.appledb.urls", downloadAppledbCmd.Flags().Lookup("urls"))
 	viper.BindPFlag("download.appledb.json", downloadAppledbCmd.Flags().Lookup("json"))
@@ -153,7 +160,9 @@ var downloadAppledbCmd = &cobra.Command{
 		pattern := viper.GetString("download.appledb.pattern")
 		fcsKeys := viper.GetBool("download.appledb.fcs-keys")
 		fcsKeysJson := viper.GetBool("download.appledb.fcs-keys-json")
+		isRelease := viper.GetBool("download.appledb.release")
 		isBeta := viper.GetBool("download.appledb.beta")
+		isRC := viper.GetBool("download.appledb.rc")
 		latest := viper.GetBool("download.appledb.latest")
 		prereqBuild := viper.GetString("download.appledb.prereq-build")
 		output := viper.GetString("download.appledb.output")
@@ -172,12 +181,18 @@ var downloadAppledbCmd = &cobra.Command{
 		if (asURLs || asJSON) && (kernel || len(pattern) > 0) {
 			return fmt.Errorf("cannot use (--urls OR --json) with (--kernel, --pattern OR --fcs-key)")
 		}
-		if isBeta && len(build) > 0 {
-			return fmt.Errorf("cannot use --beta with --build")
+		if isBeta && isRC {
+			return fmt.Errorf("cannot use --beta with --rc")
+		}
+		if (isBeta || isRC || latest) && len(build) > 0 {
+			return fmt.Errorf("cannot use --beta, --rc or --latest with --build")
 		}
 		if len(prereqBuild) > 0 && !(fwType == "ota" || fwType == "rsr") {
 			return fmt.Errorf("cannot use --prereq-build with --type %s", fwType)
 		}
+		if viper.GetBool("download.appledb.show-latest") && (asURLs || asJSON || kernel || len(pattern) > 0 || fcsKeys || fcsKeysJson) {
+			return fmt.Errorf("cannot use --show-latest with --urls, --json, --kernel, --pattern, --fcs-keys or --fcs-keys-json")
+		}
 
 		if len(apiToken) == 0 {
 			if val, ok := os.LookupEnv("GITHUB_TOKEN"); ok {
@@ -223,7 +238,9 @@ var downloadAppledbCmd = &cobra.Command{
 				Build:             build,
 				PrerequisiteBuild: prereqBuild,
 				Device:            device,
+				IsRelease:         isRelease,
 				IsBeta:            isBeta,
+				IsRC:              isRC,
 				Latest:            latest,
 				Proxy:             proxy,
 				Insecure:          insecure,
@@ -246,22 +263,74 @@ var downloadAppledbCmd = &cobra.Command{
 			} else {
 				configDir = filepath.Dir(viper.ConfigFileUsed())
 			}
-			results, err = download.LocalAppleDBQuery(&download.ADBQuery{
-				OSes:              osTypes,
-				Type:              fwType,
-				Version:           version,
-				Build:             build,
-				PrerequisiteBuild: prereqBuild,
-				Device:            device,
-				IsBeta:            isBeta,
-				Latest:            latest,
-				Proxy:             proxy,
-				Insecure:          insecure,
-				APIToken:          apiToken,
-				ConfigDir:         configDir,
-			})
-			if err != nil {
-				return err
+			if viper.GetBool("download.appledb.show-latest") {
+				latest, err := download.LocalAppleDBLatest(&download.ADBQuery{
+					OSes:              osTypes,
+					Type:              fwType,
+					Version:           version,
+					Build:             build,
+					PrerequisiteBuild: prereqBuild,
+					Device:            device,
+					IsRelease:         isRelease,
+					IsBeta:            isBeta,
+					IsRC:              isRC,
+					Latest:            latest,
+					Proxy:             proxy,
+					Insecure:          insecure,
+					APIToken:          apiToken,
+					ConfigDir:         configDir,
+				})
+				if err != nil {
+					return err
+				}
+				if latest == nil {
+					return fmt.Errorf("query return 0 results")
+				}
+				b, err := json.MarshalIndent(&struct {
+					OS       string                `os:"version"`
+					Version  string                `json:"version"`
+					Build    string                `json:"build"`
+					Beta     bool                  `json:"beta,omitempty"`
+					RC       bool                  `json:"rc,omitempty"`
+					Released download.ReleasedDate `json:"released"`
+				}{
+					OS:       latest.OS,
+					Version:  latest.Version,
+					Build:    latest.Build,
+					Beta:     latest.Beta,
+					Released: latest.Released,
+				}, "", "  ")
+				if err != nil {
+					return err
+				}
+				if viper.GetBool("color") && !viper.GetBool("no-color") {
+					if err := quick.Highlight(os.Stdout, string(b)+"\n", "json", "terminal256", "nord"); err != nil {
+						return fmt.Errorf("failed to highlight json: %v", err)
+					}
+				} else {
+					fmt.Println(string(b))
+				}
+				return nil
+			} else {
+				results, err = download.LocalAppleDBQuery(&download.ADBQuery{
+					OSes:              osTypes,
+					Type:              fwType,
+					Version:           version,
+					Build:             build,
+					PrerequisiteBuild: prereqBuild,
+					Device:            device,
+					IsRelease:         isRelease,
+					IsBeta:            isBeta,
+					IsRC:              isRC,
+					Latest:            latest,
+					Proxy:             proxy,
+					Insecure:          insecure,
+					APIToken:          apiToken,
+					ConfigDir:         configDir,
+				})
+				if err != nil {
+					return err
+				}
 			}
 		}
 
