@@ -22,10 +22,17 @@ THE SOFTWARE.
 package ota
 
 import (
+	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
 
+var colorMode = color.New(color.FgHiBlue).SprintFunc()
+var colorModTime = color.New(color.Faint).SprintFunc()
+var colorSize = color.New(color.FgHiCyan).SprintFunc()
+var colorName = color.New(color.Bold).SprintFunc()
+var colorLink = color.New(color.FgHiMagenta).SprintFunc()
+
 // OtaCmd represents the ota command
 var OtaCmd = &cobra.Command{
 	Use:   "ota",
