@@ -99,6 +99,7 @@ type Config struct {
 	Verbose       bool
 	PemDB         string
 	SignaturesDir string
+	ExtrasDir     string
 }
 
 type Ips struct {
@@ -744,13 +745,11 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 			i.Payload.BinaryImages[idx].Name = "absolute"
 			total--
 		case "Kernel":
-			i.Payload.BinaryImages[idx].Name = "kernel"
-			total--
+			fallthrough
 		case "KernelCache":
-			i.Payload.BinaryImages[idx].Name = "kernelcache"
-			total--
+			fallthrough
 		case "KernelTextExec":
-			i.Payload.BinaryImages[idx].Name = "kernelcache (__TEXT_EXEC)"
+			i.Payload.BinaryImages[idx].Name = "kernelcache"
 			total--
 		case "SharedCache":
 			i.Payload.BinaryImages[idx].Name = "dyld_shared_cache"
@@ -764,6 +763,7 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 	machoFuncMap := make(map[string][]types.Function)
 
 	/* SYMBOLICATE KERNELCACHE */
+	var kc *macho.File
 	{
 		out, err := extract.Kernelcache(&extract.Config{
 			IPSW:         ipswPath,
@@ -793,7 +793,7 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 				}
 			}
 
-			kc, err := macho.Open(k)
+			kc, err = macho.Open(k)
 			if err != nil {
 				return fmt.Errorf("failed to open kernelcache: %v", err)
 			}
@@ -841,6 +841,41 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 		}
 	}
 
+	/* SYMBOLICATE EXTRA MACHOS */
+	if i.Config.ExtrasDir != "" {
+		if err := search.ForEachMacho(i.Config.ExtrasDir, func(path string, m *macho.File) error {
+			for idx, img := range i.Payload.BinaryImages {
+				if m.UUID() != nil && strings.EqualFold(img.UUID, m.UUID().UUID.String()) {
+					i.Payload.BinaryImages[idx].Path = path
+					i.Payload.BinaryImages[idx].Name = path
+					// i.Payload.BinaryImages[idx].Name = filepath.Base(path)
+					i.Payload.BinaryImages[idx].Slide = i.Payload.BinaryImages[idx].Base - m.GetBaseAddress()
+					for _, fn := range m.GetFunctions() {
+						if syms, err := m.FindAddressSymbols(fn.StartAddr); err == nil {
+							for _, sym := range syms {
+								fn.Name = sym.Name
+							}
+							fn.StartAddr += i.Payload.BinaryImages[idx].Slide
+							fn.EndAddr += i.Payload.BinaryImages[idx].Slide
+							machoFuncMap[i.Payload.BinaryImages[idx].Name] = append(machoFuncMap[i.Payload.BinaryImages[idx].Name], fn)
+						} else {
+							fn.StartAddr += i.Payload.BinaryImages[idx].Slide
+							fn.EndAddr += i.Payload.BinaryImages[idx].Slide
+							fn.Name = fmt.Sprintf("func_%x", fn.StartAddr)
+							machoFuncMap[i.Payload.BinaryImages[idx].Name] = append(machoFuncMap[i.Payload.BinaryImages[idx].Name], fn)
+						}
+					}
+					total--
+				}
+			}
+			return nil
+		}); err != nil {
+			if !errors.Is(err, ErrDone) {
+				return fmt.Errorf("failed to symbolicate: %w", err)
+			}
+		}
+	}
+
 	/* SYMBOLICATE FILESYSTEM MACHOS */
 	if err := search.ForEachMachoInIPSW(ipswPath, i.Config.PemDB, func(path string, m *macho.File) error {
 		if total == 0 {
@@ -988,25 +1023,30 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 				}
 				if i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName == "absolute" {
 					continue // skip absolute
-				} else if i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName == "kernelcache" ||
-					i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName == "kernelcache (__TEXT_EXEC)" {
-					if funcs, ok := machoFuncMap[i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName]; ok {
-						found := false
-						for _, fn := range funcs {
-							if fn.StartAddr <= i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset &&
-								i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset < fn.EndAddr {
-								found = true
-								i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].Symbol = demangleSym(i.Config.Demangle, fn.Name)
-								if i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset-fn.StartAddr != 0 {
-									i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].SymbolLocation = i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset - fn.StartAddr
-								}
-								break
+				} else if funcs, ok := machoFuncMap[i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName]; ok {
+					found := false
+					for _, fn := range funcs {
+						if fn.StartAddr <= i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset &&
+							i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset < fn.EndAddr {
+							found = true
+							i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].Symbol = demangleSym(i.Config.Demangle, fn.Name)
+							if i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset-fn.StartAddr != 0 {
+								i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].SymbolLocation = i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset - fn.StartAddr
 							}
+							break
 						}
-						if !found {
-							// if i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName == "??" {
-							// 	i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName += " (??? maybe kext?)"
-							// }
+					}
+					if !found {
+						// if i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName == "??" {
+						// 	i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName += " (??? maybe kext?)"
+						// }
+						if seg := kc.FindSegmentForVMAddr(i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset); seg != nil {
+							i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].Symbol = seg.Name
+							if sec := kc.FindSectionForVMAddr(i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset); sec != nil {
+								i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].Symbol += "." + sec.Name
+							}
+						} else {
+							i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].Symbol = "???"
 							log.WithFields(log.Fields{
 								"proc":   fmt.Sprintf("%s [%d]", proc.Name, pid),
 								"thread": tid,
@@ -1014,13 +1054,6 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 								"img":    i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName,
 							}).Debugf("failed to find function for process offset %#x", i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset)
 						}
-					} else {
-						log.WithFields(log.Fields{
-							"proc":   fmt.Sprintf("%s [%d]", proc.Name, pid),
-							"thread": tid,
-							"frame":  idx,
-							"img":    i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName,
-						}).Debugf("failed to find function for process offset %#x", i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageOffset)
 					}
 				} else {
 					log.WithFields(log.Fields{
